# -*- coding: utf-8 -*-


class Currency(object):
    """
    Class representing currency enum
    """
    RUB = "RUB"
    USD = "USD"
    EUR = "EUR"
    BYN = "BYN"
    CNY = "CNY"
    KZT = "KZT"
    UAH = "UAH"
