# -*- coding: utf-8 -*-


class PaymentMethodType:
    """
    Constants representing payment_method_data values. Available values are:

    * yookassa.domain.common.PaymentMethodType.YOO_MONEY
    * yookassa.domain.common.PaymentMethodType.BANK_CARD
    * yookassa.domain.common.PaymentMethodType.SBERBANK
    * yookassa.domain.common.PaymentMethodType.CASH
    * yookassa.domain.common.PaymentMethodType.MOBILE_BALANCE
    * yookassa.domain.common.PaymentMethodType.PSB
    * yookassa.domain.common.PaymentMethodType.QIWI
    * yookassa.domain.common.PaymentMethodType.WEBMONEY
    * yookassa.domain.common.PaymentMethodType.ALFABANK
    * yookassa.domain.common.PaymentMethodType.APPLEPAY
    * yookassa.domain.common.PaymentMethodType.GOOGLE_PAY
    * yookassa.domain.common.PaymentMethodType.INSTALMENTS
    * yookassa.domain.common.PaymentMethodType.B2B_SBERBANK
    * yookassa.domain.common.PaymentMethodType.TINKOFF_BANK
    * yookassa.domain.common.PaymentMethodType.WECHAT
    * yookassa.domain.common.PaymentMethodType.SBP
    """
    YOO_MONEY = 'yoo_money'
    BANK_CARD = 'bank_card'
    SBERBANK = 'sberbank'
    CASH = 'cash'
    MOBILE_BALANCE = 'mobile_balance'
    PSB = 'psb'
    QIWI = 'qiwi'
    WEBMONEY = 'webmoney'
    ALFABANK = 'alfabank'
    APPLEPAY = 'apple_pay'
    GOOGLE_PAY = 'google_pay'
    INSTALMENTS = 'installments'
    B2B_SBERBANK = 'b2b_sberbank'
    TINKOFF_BANK = 'tinkoff_bank'
    WECHAT = 'wechat'
    SBP = 'sbp'
